#[non_exhaustive]pub enum IrError {
InvalidSymbol(String),
DuplicateRule(String),
Internal(String),
}Expand description
Errors that can occur while building and validating the IR.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidSymbol(String)
The referenced symbol was malformed or not present in the grammar.
DuplicateRule(String)
Attempted to insert a rule that already exists.
Internal(String)
An unexpected internal IR failure.